<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Movie;
use App\Models\Genre;
use App\Models\Page;
use App\Models\ShowName;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;
use Illuminate\View\View;
use Illuminate\Http\JsonResponse;



class AdminController extends Controller
{
    public function dashboard(){
        $movies = Movie::orderBy('views','desc')->take(5)->get();
        $latestmovies = Movie::orderBy('id','desc')->take(5)->get();
        $shows = ShowName::where('type', 1)->take(5)->get();
        $animes = ShowName::where('type',2)->take(5)->get();
        return view('admin.dashboard')->with(compact('movies','latestmovies','shows','animes'));
    }

    public function additem(){
        $genres = Genre::orderBy('name')->get();
        return view('admin.movie.additem')->with(compact('genres'));
    }    
    public function movielist(){
        $movies = Movie::orderBy('id','desc')->get();
        $genres = Genre::orderBy('name')->get();
        return view('admin.movie.movielist')->with(compact('movies','genres'));
    }

    public function saveitem(Request $request){
        
        if ($request->isMethod('post')) {

            $data = $request->all();

            // dd($data);
            $movie = new Movie;

            $cover = $request->file('cover');
            if($cover)
            {
                $image_name= str::random(5);
                $original_extension = $cover->getClientOriginalExtension();
                $image_full_name = $image_name.'.'.$original_extension;
                $upload_path = 'assets/img/movie/cover/';
                $image_url = $upload_path.$image_full_name;
                $success = $cover->move($upload_path, $image_full_name);
                $img = Image::make($image_url)->resize(190, 270)->save();
                if($success)
                {
                    $movie->cover = $image_full_name;
                }
            }
            $gallery = $request->file('gallery');
            if($gallery)
            {
                $image_name= str::random(5);
                $original_extension = $gallery->getClientOriginalExtension();
                $image_full_name = $image_name.'.'.$original_extension;
                $upload_path = 'assets/img/movie/';
                $image_url = $upload_path.$image_full_name;
                $success = $gallery->move($upload_path, $image_full_name);
                $img = Image::make($image_url)->resize(414, 280)->save();
                if($success)
                {
                    $movie->gallery = $image_full_name;
                }
            }
            $genre = implode(',', $request->genre);
            $movie->name = $data['name'];
            $movie->slug = Str::slug($data['name'], '-') ;
            $movie->description = $data['description'];
            $movie->rating = $data['rating'];
            $movie->release_year = $data['release_year'];
            $movie->minutes = $data['minutes'];
            $movie->agelimit = $data['agelimit'];
            $movie->country = $data['country'];
            $movie->views = rand(40,100);
            $movie->genre = $genre;
            $movie->vedio = $data['vedio'];
            $movie->px480 = $data['px480'];
            $movie->px720 = $data['px720'];
            $movie->px1080 = $data['px1080'];
            $movie->px4k = $data['px4k'];
            $movie->meta_keywords = $data['meta_keywords'];
            $movie->status = 1;

            
            $movie->save();

            return redirect()->back()->with('success','Blog Added Sussefully...');

        }

    }
    public function edititem($id){
        $movie = Movie::where('id',$id)->first();
        return view('admin.movie.editItem')->with(compact('movie'));
    }    


    public function updateitem(Request $request,$id){
        
        if ($request->isMethod('post')) {

            $data = $request->all();

            if(!empty($request->file('cover'))){
                $cover = $request->file('cover');
                if($cover)
                {
                    $image_name= str::random(5);
                    $original_extension = $cover->getClientOriginalExtension();
                    $image_full_name = $image_name.'.'.$original_extension;
                    $upload_path = 'assets/img/movie/cover/';
                    $image_url = $upload_path.$image_full_name;
                    $success = $cover->move($upload_path, $image_full_name);
                    $img = Image::make($image_url)->resize(190, 270)->save();
                    if($success)
                    {
                        $cover = $image_full_name;
                    }
                }
            }else{
                $cover = $data['old_cover'];
            }
            
            if($request->file('gallery')){
                $gallery = $request->file('gallery');
                if($gallery)
                {
                    $image_name= str::random(5);
                    $original_extension = $gallery->getClientOriginalExtension();
                    $image_full_name = $image_name.'.'.$original_extension;
                    $upload_path = 'assets/img/movie/';
                    $image_url = $upload_path.$image_full_name;
                    $success = $gallery->move($upload_path, $image_full_name);
                    $img = Image::make($image_url)->resize(414, 280)->save();
                    if($success)
                    {
                        $gallery = $image_full_name;
                    }
                }
            }else{
                $gallery = $data['old_image'];
            }
            // $genre = implode(',', $request->genre);
            Movie::where('id',$id)->update([
                'name'  => $data['name'],
                'description'  => $data['description'],
                'rating'  => $data['rating'],
                'release_year'  => $data['release_year'],
                'minutes'  => $data['minutes'],
                // 'genre'  => $genre,
                'vedio'  => $data['vedio'],
                'px480'  => $data['px480'],
                'px720'  => $data['px720'],
                'px1080'  => $data['px1080'],
                'meta_keywords'  => $data['meta_keywords'],
                'status'  => $data['status']
            ]);

            return redirect()->route('admin.movielist')->with('success','Movie Updated Sussefully...');

        }

    }




    public function upload(Request $request): JsonResponse
    {
        if ($request->hasFile('upload')) {
            $originName = $request->file('upload')->getClientOriginalName();
            $fileName = pathinfo($originName, PATHINFO_FILENAME);
            $extension = $request->file('upload')->getClientOriginalExtension();
            $fileName = $fileName . '_' . time() . '.' . $extension;
      
            $request->file('upload')->move(public_path('assets/img/media/'), $fileName);
      
            $url = asset('assets/img/media/' . $fileName);
  
            return response()->json(['fileName' => $fileName, 'uploaded'=> 1, 'url' => $url]);
        }
    }


    public function genreList(){
        $genre = Genre::orderBy('id','desc')->get();
        return view('admin.genre.genreList')->with(compact('genre'));
    }
    public function genreSave(Request $request){

        if ($request->isMethod('post')) {
            $request->validate([
                'name' => 'required|unique:genres'
            ]);

            $data = $request->all();
            $genre = new Genre;
            $genre->name = $data['name'];
            $genre->slug = Str::slug($data['name'], '-') ;
            $genre->views = rand(40,100);
            $genre->status = 1;

            $genre->save();

            return redirect()->back()->with('success','Genre Added Sussefully...');

        }
    }
    public function genreUpdate(Request $request,$id){
        $data = $request->all();
        Genre::where('id',$id)->update([
            'name' => $data['name'],
            'slug' => $data['slug']
        ]);

            return redirect()->back()->with('success','Genre Updated Sussefully...');


    }

    public function pageList(){
        $pages = Page::orderBy('id','desc')->get();
        return view('admin.page.pages')->with(compact('pages'));
    }
    public function pageSave(Request $request){

        if ($request->isMethod('post')) {
            $request->validate([
                'name' => 'required',
                'description' => 'required',
                'meta_keyword' => 'required',
                'meta_desc' => 'required',
            ]);

            $data = $request->all();
            $page = new Page;
            $page->name = $data['name'];
            $page->slug = Str::slug($data['name'], '-') ;
            $page->description = $data['description'];
            $page->meta_title = $data['name'];
            $page->meta_keyword = $data['meta_keyword'];
            $page->meta_desc = $data['meta_desc'];

            $page->save();

            return redirect()->back()->with('success','Page Created Sussefully...');

        }
    }



















}
