<?php

use Illuminate\Support\Facades\Route;

use App\Http\Controllers\IndexController;

use App\Http\Controllers\Admin\AdminController;
use App\Http\Controllers\Admin\BannerController;
use App\Http\Controllers\Admin\TvShowController;
use App\Http\Controllers\Admin\AdminLoginController;
use App\Http\Controllers\SocialLoginController;

// Route::get('/', function () {
//     return view('welcome');
// });

Route::get('/', [IndexController::class, 'index'])->name('home.index');
Route::get('/movies', [IndexController::class, 'movies'])->name('home.movies');
Route::get('/tv-shows', [IndexController::class, 'tvshows'])->name('home.tvshows');
Route::get('/anime', [IndexController::class, 'anime'])->name('home.anime');
Route::get('/episodes/{slug}', [IndexController::class, 'tvshowepisodes'])->name('home.tvshowdepisodes');

Route::get('/tv-show/{slug}', [IndexController::class, 'tvshowDetails'])->name('home.tvshowdetail');

Route::get('/anime', [IndexController::class, 'anime'])->name('home.anime');
Route::get('/movie/{slug}', [IndexController::class, 'movieDetails'])->name('home.movieDetails');

Route::get('/genre/{slug}', [IndexController::class, 'byGenre'])->name('home.byGenre');

Route::get('/load-more-data', [IndexController::class,'loadMoreData'])->name('load.more');

Route::get('/contact-us', [IndexController::class, 'contact'])->name('home.contact');
Route::post('/save-message', [IndexController::class, 'savemessage'])->name('home.contactsave');

Route::get('/sitemap.xml', [IndexController::class, 'sitemap'])->name('home.sitemap');

Auth::routes();

Route::get('/search', [IndexController::class, 'autocomplete'])->name('home.search');
Route::get('/p/{slug}', [IndexController::class, 'pagedetails'])->name('home.pagedetails');


Route::prefix('admin')->group(function () {
    Route::get('/login', [AdminLoginController::class, 'login'])->name('admin.login');
    Route::post('/signin', [AdminLoginController::class, 'authenticate'])->name('signin');
    Route::post('ckeditor/upload', [AdminController::class, 'upload'])->name('ckeditor.upload');


    Route::group(['middleware' => ['auth:admin', 'admin']], function(){
        Route::get('/dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');
        Route::get('/movie-list', [AdminController::class, 'movielist'])->name('admin.movielist');

        Route::get('/add-item', [AdminController::class, 'additem'])->name('admin.additem');
        Route::get('/edit-item/{id}', [AdminController::class, 'edititem'])->name('admin.edititem');

        Route::post('/save-item', [AdminController::class, 'saveitem'])->name('admin.saveitem');
        Route::post('/update-item/{id}', [AdminController::class, 'updateitem'])->name('admin.updateitem');
        
        
        Route::get('/banners', [BannerController::class, 'bannerList'])->name('banner.list');
        Route::get('/add-banner', [BannerController::class, 'bannerAdd'])->name('banner.add');
        Route::get('/edit-banner/{id}', [BannerController::class, 'bannerEdit'])->name('banner.edit');
        Route::post('/update-banner/{id}', [BannerController::class, 'bannerUpdate'])->name('banner.update');
        Route::post('/save-banner', [BannerController::class, 'bannerSave'])->name('banner.save');        
        
        Route::get('/tv-shows', [TvShowController::class, 'tvshows'])->name('tvshow.list');
        Route::get('/add-tvshow', [TvShowController::class, 'tvshowAdd'])->name('tvshow.add');
        Route::post('/save-tvshow', [TvShowController::class, 'tvshowSave'])->name('tvshow.save');

        Route::get('/tv-show-episods/{id}', [TvShowController::class, 'tvshowEpisod'])->name('tvshow.episodlist');
        Route::get('/add-show-episod/{id}', [TvShowController::class, 'episodAdd'])->name('tvshow.episodadd');
        Route::post('/save-show-episod', [TvShowController::class, 'episodSave'])->name('tvshow.episodSave');

        Route::get('/genre/list', [AdminController::class, 'genreList'])->name('genre.list');
        Route::post('/genre/save', [AdminController::class, 'genreSave'])->name('genre.save');
        Route::post('/genre/update/{id}', [AdminController::class, 'genreUpdate'])->name('genre.update');

        Route::get('/pages/list', [AdminController::class, 'pageList'])->name('page.list');
        Route::post('/pages/save', [AdminController::class, 'pageSave'])->name('page.save');

        Route::get('/logout', [AdminLoginController::class, 'logout'])->name('admin.logut');

    
    });
});

Route::get('/redirect/google', [SocialLoginController::class, 'redirectToGoogle'])->name('google.login');
Route::get('/social-login/google/callback', [SocialLoginController::class, 'handleProviderCallback'])->name('google.callback');



Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
